// Admin

;(function ($, window, document) {
    'use strict';

    const idPrefix = 'woocommerce_wc_fintecture_gateway_';
    let environment = false;

    const successIcon = '<span class="dashicons dashicons-yes"></span>';
    const errorIcon = '<span class="dashicons dashicons-no"></span>';

    const fields = {
        app_id: idPrefix + 'app_id',
        app_secret: idPrefix + 'app_secret',
        app_private_key: idPrefix + 'app_private_key',
        test_app_id: idPrefix + 'test_app_id',
        test_app_secret: idPrefix + 'test_app_secret',
        test_app_private_key: idPrefix + 'test_app_private_key',
        environment: idPrefix + 'environment',
        test_production_button: 'fintecture-btn-test-prod-js',
        test_sandbox_button: 'fintecture-btn-test-sandbox-js'
    };

    var validateForm = {
        init: function() {
            setEnvironment();
            $('#' + fields.environment).on('change', setEnvironment());
            $('button[type="submit"]').on('click', this.onClickValidate);
        },
        onClickValidate: function(event) {
            var invalid_fields = validateForm.checkInvalidFields();

            if(invalid_fields.length)
                event.preventDefault();
        },
        checkInvalidFields: function() {
            setEnvironment();

            let fields_to_validate = [];
            let invalid_fields = [];

            $('.validation-js').remove();
            const container = '<p class="validation-js"></p>';

            if (environment === 'production') {
                fields_to_validate = ['app_id', 'app_secret'];
            }
            else if (environment === 'sandbox') {
                fields_to_validate = ['test_app_id', 'test_app_secret'];
            }

            $.each(fields_to_validate, function(i) {
                const element = $('#' + fields[fields_to_validate[i]]).val();

                if(element === '' || element === undefined) {
                    $('#' + fields[fields_to_validate[i]]).parent().append(container);
                    $('#' + fields[fields_to_validate[i]])
                        .parent()
                        .find('.validation-js')
                        .addClass('fintecture-error')
                        .html(errorIcon + script_vars.mandatory);
                    invalid_fields.push(fields[fields_to_validate[i]]);
                }
            });

            return invalid_fields;
        }
    };

    var setEnvironment = () => {
        environment = $('#' + fields.environment).prop('checked') ? 'sandbox' : 'production';
    };

    var testConnection = {
        init: function() {
            var production_button = $('.' + fields.test_production_button);
            var sandbox_button = $('.' + fields.test_sandbox_button);

            production_button.click((event) => {
                event.preventDefault();
                this.getData('production');
            });
            sandbox_button.click((event) => {
                event.preventDefault();
                this.getData('sandbox');
            });
        },
        getData: function(environment) {
            let app_id = '';
            let app_secret = '';
            let private_key = '';
            let private_key_file = undefined;

            switch (environment) {
                case 'production':
                    app_id = $('#' + fields.app_id).val();
                    app_secret = $('#' + fields.app_secret).val();
                    private_key_file = $('#' + fields.app_private_key);
                    break;
                case 'sandbox':
                    app_id = $('#' + fields.test_app_id).val();
                    app_secret = $('#' + fields.test_app_secret).val();
                    private_key_file = $('#' + fields.test_app_private_key);
                    break;
            }
            
            // Read uploaded file if defined
            if (0 in private_key_file && 0 in private_key_file[0].files) { // check if index exists
                readFile(private_key_file[0].files[0], function(e) {
                    private_key = e.target.result;
                    testConnection.makeRequest({ environment, app_id, app_secret, private_key });
                });
            }
            else {
                testConnection.makeRequest({ environment, app_id, app_secret, private_key })
            }
        },
        makeRequest: function(data) {
            $.ajax(script_vars.connection_test_url, {
                'type': 'POST',
                'headers': {
                    'Accept': 'application/json',
                    'Content-Type': 'application/x-www-form-urlencoded'
                },
                'data' : { 
                    'environment': data.environment,
                    'app_id': data.app_id,
                    'app_secret': data.app_secret,
                    'private_key':  data.private_key
                }
            })
            .always((_result, textStatus, _jqXHR) => {
                testConnection.writeResponse(textStatus, data.environment);
            });
        },
        writeResponse: function(status, environment) {
            $('.test-result-js').remove();

            let resultElement = '';
            const container = '<p class="test-result-js"></p>';

            switch (environment) {
                case 'production':
                    $('.' + fields.test_production_button).parent().append(container);
                    resultElement = $('.' + fields.test_production_button).parent().find('.test-result-js');
                    break;
                case 'sandbox':
                    $('.' + fields.test_sandbox_button).parent().append(container);
                    resultElement = $('.' + fields.test_sandbox_button).parent().find('.test-result-js');
                    break;
            };

            resultElement.addClass(status === 'success' ? 'fintecture-success' : 'fintecture-error');
            resultElement.html(status === 'success' ? successIcon + script_vars.success : errorIcon + script_vars.failed);
        }
    }

    var run = () => {
        validateForm.init(),
        testConnection.init()
    };

    $(run);
}(jQuery));

// Function to read content of a file
function readFile(file, onLoadCallback){
    var reader = new FileReader();
    reader.onload = onLoadCallback;
    reader.readAsText(file);
}