<?php

namespace FintectureWC;

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://fintecture.com
 * @since             1.0
 * @package           Fintecture_Gateway
 *
 * @wordpress-plugin
 * Plugin Name:       Pay by Instant Transfer (by Fintecture)
 * Description:       Extends WooCommerce by enabling users to pay securely and directly from their bank account
 * Version:           3.2.4
 * Author:            Fintecture
 * Author URI:        https://www.fintecture.com/
 * License:           GPLv3
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.txt
 * Requires PHP: 7.2
 * Requires at least: 5.0
 * WC requires at least: 3.9
 * WC tested up to: 6.9
 */
require_once \plugin_dir_path(__FILE__) . 'includes/fix-for-php-scoper.php';
require_once \plugin_dir_path(__FILE__) . 'includes/constants.php';
require_once \plugin_dir_path(__FILE__) . 'includes/stats.php';
require_once \plugin_dir_path(__FILE__) . 'includes/logger.php';
require_once \plugin_dir_path(__FILE__) . 'includes/post-payment-validator.php';
require_once \plugin_dir_path(__FILE__) . 'includes/webhook.php';
require_once \plugin_dir_path(__FILE__) . 'vendor/scoper-autoload.php';
use FintectureWC\Fintecture\Config\Telemetry;
if (!\defined('ABSPATH')) {
    exit;
}
/**
 * This action hook registers our PHP class as a WooCommerce payment gateway
 *
 * @param array<mixed> $gateways
 * @return array<mixed>
 */
function fintecture_add_gateway_class($gateways)
{
    $gateways[] = __NAMESPACE__ . '\\Fintecture_Post_Payment';
    // class name of gateway
    return $gateways;
}
\add_filter('woocommerce_payment_gateways', __NAMESPACE__ . '\\fintecture_add_gateway_class');
/**
 * This action hook permit to add a 'Settings' link inside plugin section
 *
 * @param array<mixed> $links
 * @return array<mixed>
 */
function fintecture_action_links($links)
{
    $plugin_links = ['<a href="' . \admin_url('admin.php?page=wc-settings&tab=checkout') . '">' . \__('Settings', 'fintecture-payment-gateway') . '</a>'];
    return \array_merge($plugin_links, $links);
    // Merge our new link with the default ones
}
\add_filter('plugin_action_links_' . \plugin_basename(__FILE__), __NAMESPACE__ . '\\fintecture_action_links');
if (!\class_exists('FintectureWC\\WC_Fintecture_Main')) {
    class WC_Fintecture_Main
    {
        /**
         * Instance of the current class, null before first usage.
         *
         * @var WC_Fintecture_Main
         */
        protected static $instance = null;
        /**
         * Class constructor
         * @since 0.1
         */
        protected function __construct()
        {
            // Core class
            require_once \plugin_dir_path(__FILE__) . 'includes/class-wc-fintecture-payment-gateway.php';
        }
        /**
         * Install procedure
         *
         * @return void|false
         * @static
         * @since 2.3
         */
        public static function install()
        {
            if (!\current_user_can('activate_plugins')) {
                return \false;
            }
            try {
                Telemetry::logAction('install', fintecture_system_infos());
            } catch (\Exception $e) {
                fintecture_write_log('Can\'t send telemetry call: ' . $e);
            }
        }
        /**
         * Disable procedure
         *
         * @return void|false
         * @static
         * @since 2.3
         */
        public static function disable()
        {
            if (!\current_user_can('activate_plugins')) {
                return \false;
            }
            try {
                Telemetry::logAction('disable', fintecture_system_infos());
            } catch (\Exception $e) {
                fintecture_write_log('Can\'t send telemetry call: ' . $e);
            }
        }
        /**
         * Uninstallation procedure
         *
         * @return void|false
         * @static
         * @since 2.3
         */
        public static function uninstall()
        {
            if (!\current_user_can('activate_plugins')) {
                return \false;
            }
            try {
                Telemetry::logAction('uninstall', fintecture_system_infos());
            } catch (\Exception $e) {
                fintecture_write_log('Can\'t send telemetry call: ' . $e);
            }
        }
        /**
         * Return class instance
         *
         * @static
         * @since 2.3
         * @return WC_Fintecture_Main
         */
        public static function get_instance()
        {
            /** @phpstan-ignore-next-line */
            if (\is_null(self::$instance)) {
                self::$instance = new self();
            }
            return self::$instance;
        }
        /**
         * Cloning is forbidden
         *
         * @since 2.3
         */
        public function __clone()
        {
            /** @phpstan-ignore-next-line */
            return \wp_die('Cloning is forbidden!');
        }
    }
}
\register_activation_hook(__FILE__, [__NAMESPACE__ . '\\WC_Fintecture_Main', 'install']);
\register_deactivation_hook(__FILE__, [__NAMESPACE__ . '\\WC_Fintecture_Main', 'disable']);
\register_uninstall_hook(__FILE__, [__NAMESPACE__ . '\\WC_Fintecture_Main', 'uninstall']);
\add_action('plugins_loaded', [__NAMESPACE__ . '\\WC_Fintecture_Main', 'get_instance'], 0);
