<?php

namespace FintectureWC\Http\Discovery\Strategy;

use FintectureWC\Psr\Http\Message\RequestFactoryInterface;
use FintectureWC\Psr\Http\Message\ResponseFactoryInterface;
use FintectureWC\Psr\Http\Message\ServerRequestFactoryInterface;
use FintectureWC\Psr\Http\Message\StreamFactoryInterface;
use FintectureWC\Psr\Http\Message\UploadedFileFactoryInterface;
use FintectureWC\Psr\Http\Message\UriFactoryInterface;
/**
 * @internal
 *
 * @author Tobias Nyholm <tobias.nyholm@gmail.com>
 */
final class CommonPsr17ClassesStrategy implements DiscoveryStrategy
{
    /**
     * @var array
     */
    private static $classes = [RequestFactoryInterface::class => ['FintectureWC\\Phalcon\\Http\\Message\\RequestFactory', 'FintectureWC\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'FintectureWC\\Zend\\Diactoros\\RequestFactory', 'FintectureWC\\GuzzleHttp\\Psr7\\HttpFactory', 'FintectureWC\\Http\\Factory\\Diactoros\\RequestFactory', 'FintectureWC\\Http\\Factory\\Guzzle\\RequestFactory', 'FintectureWC\\Http\\Factory\\Slim\\RequestFactory', 'FintectureWC\\Laminas\\Diactoros\\RequestFactory', 'FintectureWC\\Slim\\Psr7\\Factory\\RequestFactory'], ResponseFactoryInterface::class => ['FintectureWC\\Phalcon\\Http\\Message\\ResponseFactory', 'FintectureWC\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'FintectureWC\\Zend\\Diactoros\\ResponseFactory', 'FintectureWC\\GuzzleHttp\\Psr7\\HttpFactory', 'FintectureWC\\Http\\Factory\\Diactoros\\ResponseFactory', 'FintectureWC\\Http\\Factory\\Guzzle\\ResponseFactory', 'FintectureWC\\Http\\Factory\\Slim\\ResponseFactory', 'FintectureWC\\Laminas\\Diactoros\\ResponseFactory', 'FintectureWC\\Slim\\Psr7\\Factory\\ResponseFactory'], ServerRequestFactoryInterface::class => ['FintectureWC\\Phalcon\\Http\\Message\\ServerRequestFactory', 'FintectureWC\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'FintectureWC\\Zend\\Diactoros\\ServerRequestFactory', 'FintectureWC\\GuzzleHttp\\Psr7\\HttpFactory', 'FintectureWC\\Http\\Factory\\Diactoros\\ServerRequestFactory', 'FintectureWC\\Http\\Factory\\Guzzle\\ServerRequestFactory', 'FintectureWC\\Http\\Factory\\Slim\\ServerRequestFactory', 'FintectureWC\\Laminas\\Diactoros\\ServerRequestFactory', 'FintectureWC\\Slim\\Psr7\\Factory\\ServerRequestFactory'], StreamFactoryInterface::class => ['FintectureWC\\Phalcon\\Http\\Message\\StreamFactory', 'FintectureWC\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'FintectureWC\\Zend\\Diactoros\\StreamFactory', 'FintectureWC\\GuzzleHttp\\Psr7\\HttpFactory', 'FintectureWC\\Http\\Factory\\Diactoros\\StreamFactory', 'FintectureWC\\Http\\Factory\\Guzzle\\StreamFactory', 'FintectureWC\\Http\\Factory\\Slim\\StreamFactory', 'FintectureWC\\Laminas\\Diactoros\\StreamFactory', 'FintectureWC\\Slim\\Psr7\\Factory\\StreamFactory'], UploadedFileFactoryInterface::class => ['FintectureWC\\Phalcon\\Http\\Message\\UploadedFileFactory', 'FintectureWC\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'FintectureWC\\Zend\\Diactoros\\UploadedFileFactory', 'FintectureWC\\GuzzleHttp\\Psr7\\HttpFactory', 'FintectureWC\\Http\\Factory\\Diactoros\\UploadedFileFactory', 'FintectureWC\\Http\\Factory\\Guzzle\\UploadedFileFactory', 'FintectureWC\\Http\\Factory\\Slim\\UploadedFileFactory', 'FintectureWC\\Laminas\\Diactoros\\UploadedFileFactory', 'FintectureWC\\Slim\\Psr7\\Factory\\UploadedFileFactory'], UriFactoryInterface::class => ['FintectureWC\\Phalcon\\Http\\Message\\UriFactory', 'FintectureWC\\Nyholm\\Psr7\\Factory\\Psr17Factory', 'FintectureWC\\Zend\\Diactoros\\UriFactory', 'FintectureWC\\GuzzleHttp\\Psr7\\HttpFactory', 'FintectureWC\\Http\\Factory\\Diactoros\\UriFactory', 'FintectureWC\\Http\\Factory\\Guzzle\\UriFactory', 'FintectureWC\\Http\\Factory\\Slim\\UriFactory', 'FintectureWC\\Laminas\\Diactoros\\UriFactory', 'FintectureWC\\Slim\\Psr7\\Factory\\UriFactory']];
    /**
     * {@inheritdoc}
     */
    public static function getCandidates($type)
    {
        $candidates = [];
        if (isset(self::$classes[$type])) {
            foreach (self::$classes[$type] as $class) {
                $candidates[] = ['class' => $class, 'condition' => [$class]];
            }
        }
        return $candidates;
    }
}
